@@ -1,5 +1,5 @@
-__version__ = "0.0.2"
-__author__ = "Pablo Velasco"
+__version__ = "1.3.0"
+__author__ = "Pablo Velasco, Chrysa Papadaniil"
 __author_email__ = "pablo.velasco@nyu.edu"
 __url__ = "https://github.com/cbinyu/bidsphysio"
 __packagename__ = 'bidsphysio.base'
